atomate.vasp.workflows.tests package — atomate 0.9.2 documentation

# atomate.vasp.workflows.tests package

## Submodules

## atomate.vasp.workflows.tests.test_adsorbate_workflow module

class `atomate.vasp.workflows.tests.test_adsorbate_workflow.` `TestAdsorptionWorkflow`(methodName='runTest')

  Bases: `atomate.utils.testing.AtomateTest`

  `setUp`()

    Create scratch directory(removes the old one if there is one) and change to it. Also initialize launchpad.

  `test_input_sets`()
  `test_wf`()
  `test_wf_functions`()

## atomate.vasp.workflows.tests.test_bulk_modulus_workflow module

class `atomate.vasp.workflows.tests.test_bulk_modulus_workflow.` `TestBulkModulusWorkflow`(methodName='runTest')

  Bases: `atomate.utils.testing.AtomateTest`

  This test will either actually run VASP (if VASP_CMD is set) or artificially pass on outputs (if not VASP_CMD) and test the whole bulk modulus workflow and its implementation and outputs for an example calculation for silicon.

  note for the developer of the test: This tests can be run in two modes if not VASP_CMD: 1. first all inputs and outputs of all deformations are present in which case

  > in each folder a trimmed version of task.json will be generated so that

  2. once task.json is present, VaspRun can be skipped where task.json is

       available and their “inputs” and “outputs” folders can be removed

  `setUp`()

    Create scratch directory(removes the old one if there is one) and change to it. Also initialize launchpad.

  `setup_task_docs`()
  `test_wf`()
  `write_task_docs`()

## atomate.vasp.workflows.tests.test_elastic_workflow module

class `atomate.vasp.workflows.tests.test_elastic_workflow.` `TestElasticWorkflow`(methodName='runTest')

  Bases: `atomate.utils.testing.AtomateTest`

  `setUp`()

    Create scratch directory(removes the old one if there is one) and change to it. Also initialize launchpad.

  `test_wf`()

## atomate.vasp.workflows.tests.test_ferroelectric_workflow module

class `atomate.vasp.workflows.tests.test_ferroelectric_workflow.` `TestFerroelectricWorkflow`(methodName='runTest')

  Bases: `atomate.utils.testing.AtomateTest`

  `setUp`()

    Create scratch directory(removes the old one if there is one) and change to it. Also initialize launchpad.

  `test_wf`()
  `untarTestFiles`()

## atomate.vasp.workflows.tests.test_magnetism_workflow module

class `atomate.vasp.workflows.tests.test_magnetism_workflow.` `TestMagneticDeformationWorkflow`(methodName='runTest')

  Bases: `atomate.utils.testing.AtomateTest`

  `test_analysis`()

class `atomate.vasp.workflows.tests.test_magnetism_workflow.` `TestMagneticOrderingsWorkflow`(methodName='runTest')

  Bases: `atomate.utils.testing.AtomateTest`

  `test_analysis`()
  `test_ordering_enumeration`()

## atomate.vasp.workflows.tests.test_neb_workflow module

class `atomate.vasp.workflows.tests.test_neb_workflow.` `TestNudgedElasticBandWorkflow`(methodName='runTest')

  Bases: `atomate.utils.testing.AtomateTest`

  `setUp`()

    1. Basic check for pymatgen configurations.

    2. Setup all test workflow.

  `test_wf`()

## atomate.vasp.workflows.tests.test_nmr module

class `atomate.vasp.workflows.tests.test_nmr.` `TestNMRWorkflow`(methodName='runTest')

  Bases: `atomate.utils.testing.AtomateTest`

  This test will either actually run VASP (if VASP_CMD is set) or artificially pass on outputs (if not VASP_CMD) and test the NMR workflow and its implementation and outputs for an example calculation for LiAlSiO4.

  `setUp`()

    Create scratch directory(removes the old one if there is one) and change to it. Also initialize launchpad.

  `test_wf`()

## atomate.vasp.workflows.tests.test_raman_workflow module

class `atomate.vasp.workflows.tests.test_raman_workflow.` `TestRamanWorkflow`(methodName='runTest')

  Bases: `atomate.utils.testing.AtomateTest`

  `setUp`()

    Create scratch directory(removes the old one if there is one) and change to it. Also initialize launchpad.

  `test_wf`()

## atomate.vasp.workflows.tests.test_vasp_workflows module

class `atomate.vasp.workflows.tests.test_vasp_workflows.` `TestVaspWorkflows`(methodName='runTest')

  Bases: `atomate.utils.testing.AtomateTest`

  `setUp`()

    Create scratch directory(removes the old one if there is one) and change to it. Also initialize launchpad.

  `test_bandgap_check_Vasp`()
  `test_bandstructure_Vasp`()
  `test_chgcar_db_read`()
  `test_chgcar_db_read_write`()
  `test_single_Vasp`()
  `test_single_Vasp_dbinsertion`()
  `test_trackers`()

## Module contents